<template>
    <div>
        <list-condition-template ref="table" :form="listQuery" :formLabel="formLabel" :tableData="tableData" :total="total" @page-info-change="handlePageInfoChange">
            <template slot="otherElement">
              <el-form-item>
                <el-button size="mini" type="primary" @click="queryData">查询</el-button>
                <el-button size="mini" @click="resetQuery">重置</el-button>
              </el-form-item>
            </template>
            <template slot="operationSection">
                <el-button size="mini" type="success" @click="addItem">新增推送</el-button>
            </template>
            <template slot="columns">
                <el-table-column label="消息名称" prop="title" show-overflow-tooltip></el-table-column>
                <el-table-column label="消息编号" prop="messageNo" show-overflow-tooltip></el-table-column>
                <el-table-column label="消息类型" prop="messageType">
                  <template slot-scope="scope">
                    {{getArrayLable(formLabel[4].opts,scope.row.messageType)}}
                  </template>
                </el-table-column>
                <el-table-column label="推送时间"  width="300px">
                  <template slot-scope="scope">
                    <span>{{scope.row.sendTime}}</span>
                  </template>
                </el-table-column>
                <el-table-column label="操作" :width="`${3 * $store.getters.colSize}px`">
                    <template slot-scope="scope">
                       <wly-btn @click="detailsInfo(scope.row,scope.$index)" >详情</wly-btn>
                       <wly-btn v-if="scope.row.editType === '1' && scope.row.stopType === '1'"  type="primary" @click="editItem(scope.row,scope.$index)" >编辑</wly-btn>
                       <wly-btn v-if="scope.row.editType === '1' && scope.row.stopType === '1'"  type="danger" @click="stopPush(scope.row,scope.$index)" >停止推送</wly-btn>
                    </template>
                </el-table-column>
            </template>
        </list-condition-template>
        <el-dialog :visible.sync="dialogVisible" title="推送消息详情" class="proActivity"  :close-on-click-modal="false" :modal-append-to-body="false" width="40%">
            <details-info :form="form"></details-info>
            <div slot="footer" class="dialog-footer">
                <el-button size="mini" @click="dialogVisible=false">关闭</el-button>
            </div>
        </el-dialog>
    </div>
</template>
<script>
import messagePushApi from '@/api/messageMgt/messagePush'
import detailsInfo from '@/views/messageMgt/messagePush/components/detailsInfo.vue'
import { getArrayLable } from '@/utils/getArrayLable'

var _this = null

export default {
  components: {
    detailsInfo
  },
  data () {
    return {
      tableData: [],
      total: 0,
      dialogVisible: false,
      listQuery: {
        title: null,
        messageNo: null,
        messageType: null,
        startTime: null,
        endTime: null
      },
      form: {},
      formLabel: [
        {
          model: 'startTime',
          label: '推送时间',
          type: 'date',
          pickerOptions: {
            disabledDate (time) {
              return _this.listQuery.endTime && time.getTime() >= new Date(_this.listQuery.endTime).getTime() + 86400000
            }
          },
          timeClass: 'start-time-style'
        },
        {
          model: 'endTime',
          label: '-',
          customLabel: '推送时间',
          labelWidth: '20px',
          type: 'date',
          pickerOptions: {
            disabledDate (time) {
              return _this.listQuery.startTime && time.getTime() <= new Date(_this.listQuery.startTime).getTime() - 86400000
            }
          },
          timeClass: 'end-time-style'
        },
        {
          model: 'title',
          label: '消息名称',
          type: 'input'
        },
        {
          model: 'messageNo',
          label: '消息编号',
          type: 'input',
          rule: /[^\w]/g // 可输入数字字母
        },
        {
          model: 'messageType',
          label: '消息类型',
          type: 'select',
          opts: [
            {
              id: '1',
              name: '商品推送'
            },
            // {
            //   id: '2',
            //   name: '文章推送'
            // },
            {
              id: '3',
              name: '系统消息'
            },
            {
              id: '4',
              name: '活动消息'
            }
          ]
        }
      ]
    }
  },
  /*
     * 数据变化后刷新列表
   */
  activated () {
    this.queryList(this.$refs.table.getPageInfo())
  },
  created () {
    _this = this
  },
  methods: {
    /**
     * 停止推送
     */
    stopPush (row, index) {
      messagePushApi.stopPush({ id: row.id }).then(res => {
        if (res.code === '0') {
          this.$message({
            message: '停止推送成功',
            type: 'info'
          })
          this.$refs.table.changeCondition()
        }
      })
    },
    /**
     * 查看详情
     */
    detailsInfo (row, index) {
      messagePushApi.detailsInfo({ id: row.id }).then(res => {
        if (res.data) {
          this.form = res.data
          this.dialogVisible = true
        }
      })
    },
    /**
     * 获取数组的label
     */
    getArrayLable,
    /**
     * 新增
     */
    addItem () {
      this.$router.push({ name: 'messagePushInfo' })
    },
    /**
     * 编辑
     */
    editItem (row, index) {
      this.$router.push({ name: 'editMessagePush', query: { id: row.id } })
    },
    /**
       * '分页信息改变时查询列表
       */
    handlePageInfoChange (pageInfo) {
      this.queryList(pageInfo)
    },

    /**
     * 重置
     */
    resetQuery () {
      this.$refs.table.reloadCurrent()
    },
    /**
     * 点击查询按钮
     */
    queryData () {
      this.$refs.table.changeCondition()
    },
    /**
     * 查询列表
     */
    queryList (pageInfo = { pageNum: 1, pageSize: 10 }) {
      const q = this.listQuery.endTime && this.listQuery.startTime === this.listQuery.endTime
      if (q) {
        this.listQuery.endTime = this.listQuery.endTime.substring(0, 11) + '23:59:59'
      }
      messagePushApi.getList({ ...this.listQuery, ...pageInfo }).then(res => {
        if (res.data) {
          this.tableData = res.data.list
          this.total = res.data.total
        }
      })
    }
  }
}
</script>
<style lang="scss">
</style>
